@@ -16,21 +16,13 @@
 #include <dbus/dbus.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#ifdef BUILD_BORA
-# include <hildon-widgets/hildon-program.h>
-# include <hildon-widgets/gtk-infoprint.h>
-# include <hildon-widgets/hildon-window.h>
-# include <hildon-widgets/hildon-seekbar.h>
-# include <hildon-widgets/hildon-file-chooser-dialog.h>
-#else
-# include <hildon/hildon-defines.h>
-# include <hildon/hildon-program.h>
-# include <hildon/hildon-window.h>
-# include <hildon/hildon-note.h>
-# include <hildon/hildon-seekbar.h>
-# include <hildon/hildon-file-chooser-dialog.h>
-# include <hildon/hildon-banner.h>
-#endif
+#include <hildon/hildon-defines.h>
+#include <hildon/hildon-program.h>
+#include <hildon/hildon-window.h>
+#include <hildon/hildon-note.h>
+#include <hildon/hildon-seekbar.h>
+#include <hildon/hildon-file-chooser-dialog.h>
+#include <hildon/hildon-banner.h>
 
 #define bool char
 #define true 1
@@ -137,17 +129,23 @@ static gboolean delayed_open_location (OpenLocation *ol) {
 void app_set_playing (Application *app, int p) {
     app->playing = p;
     if (PLAYING == p) {
+        gtk_widget_show (GTK_WIDGET (app->tb_prev));
         gtk_widget_hide (GTK_WIDGET (app->tb_play));
         gtk_widget_show (GTK_WIDGET (app->tb_pause));
+        gtk_widget_show (GTK_WIDGET (app->tb_next));
         gtk_widget_hide (GTK_WIDGET (app->tb_save));
         gtk_widget_show (GTK_WIDGET (app->tb_stop));
     } else {
         gtk_widget_hide (GTK_WIDGET (app->tb_pause));
         gtk_widget_show (GTK_WIDGET (app->tb_play));
         if (NOT_PLAYING == p) {
+            gtk_widget_hide (GTK_WIDGET (app->tb_prev));
             gtk_widget_hide (GTK_WIDGET (app->tb_stop));
+            gtk_widget_hide (GTK_WIDGET (app->tb_next));
             gtk_widget_show (GTK_WIDGET (app->tb_save));
         } else {
+            gtk_widget_show (GTK_WIDGET (app->tb_prev));
+            gtk_widget_show (GTK_WIDGET (app->tb_next));
             gtk_widget_hide (GTK_WIDGET (app->tb_save));
             gtk_widget_show (GTK_WIDGET (app->tb_stop));
         }
@@ -172,10 +170,6 @@ void app_full_screen (Application *app) {
         if (!app->window_fullscreen) {
             HildonWindow *win = HILDON_WINDOW (hildon_stackable_window_new ());
             app->window_fullscreen = GTK_WINDOW (win);
-            app->view_area_fullscreen = gtk_drawing_area_new ();
-            gtk_container_add (GTK_CONTAINER (win),
-                    app->view_area_fullscreen);
-            _app_setup_window (app->view_area_fullscreen, app);
             hildon_program_add_window (HILDON_PROGRAM (app->program), win);
             /*g_signal_connect (G_OBJECT (win), "map-event",
                     GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
@@ -185,8 +179,11 @@ void app_full_screen (Application *app) {
                     GTK_SIGNAL_FUNC (cb_fullscreen_destoyed), app);
             g_signal_connect (G_OBJECT (win), "key-press-event",
                     GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
+            gtk_widget_realize (GTK_WIDGET (app->window_fullscreen));
         }
         app->fullscreen = true;
+
+        gtk_widget_reparent (app->view_area, GTK_WIDGET (app->window_fullscreen));
         gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
         cbViewAreaFullscreenMapped (GTK_WIDGET (app->window_fullscreen), NULL, app);
         app_update_screen_blanking (app);
@@ -196,6 +193,10 @@ void app_full_screen (Application *app) {
 void app_normal_screen (Application *app) {
     if (app->fullscreen) {
         app->fullscreen = false;
+
+        gtk_widget_reparent (app->view_area, app->view_base);
+        gtk_container_resize_children (GTK_CONTAINER (app->view_base));
+
         hildon_window_stack_pop_1 (hildon_window_stack_get_default ());
         cbViewAreaFullscreenUnmapped (GTK_WIDGET (app->window_fullscreen), app);
     }
@@ -234,16 +235,6 @@ static void callback_file_go (GtkButton *button, Application *app) {
     }
 }
 
-static void callback_file_export_m3u (GtkButton *button, Application *app) {
-    (void) button;
-    saveFile (app, false);
-}
-
-static void callback_file_export_xml (GtkButton *button, Application *app) {
-    (void) button;
-    saveFile (app, true);
-}
-
 static void callback_file_new (GtkButton * button, Application * app) {
     newFile (app);
     gtk_window_set_title (app->window, "");
@@ -300,9 +291,6 @@ static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
 static void create_toolbar (Application * app) {
     /* Create needed variables */
     GtkToolItem *tb_open;
-    GtkToolItem *tb_prev;
-    GtkToolItem *tb_next;
-    GtkToolItem *tb_go;
     GtkToolItem *tb_separator;
 
     /* Create toolbar */
@@ -310,13 +298,13 @@ static void create_toolbar (Application * app) {
 
     /* Create toolbar button items */
     tb_open = gtk_tool_button_new_from_stock (GTK_STOCK_OPEN);
-    tb_prev = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PREVIOUS);
+    app->tb_prev = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PREVIOUS);
     app->tb_play = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
     app->tb_pause = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
-    tb_next = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_NEXT);
+    app->tb_next = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_NEXT);
     app->tb_stop = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_STOP);
     app->tb_save = gtk_tool_button_new_from_stock (GTK_STOCK_SAVE);
-    tb_go = gtk_tool_button_new (gtk_image_new_from_icon_name(
+    app->tb_go = gtk_tool_button_new (gtk_image_new_from_icon_name(
                 "widgets_tickmark_grid", HILDON_ICON_SIZE_TOOLBAR), NULL);
     app->tb_item_playlist_commit = GTK_WIDGET (gtk_tool_button_new (
                 gtk_image_new_from_icon_name(
@@ -347,29 +335,29 @@ static void create_toolbar (Application * app) {
     /* Add all items to toolbar */
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_location, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_progress, -1);
-    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_go, -1);
+    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_go, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_open, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), GTK_TOOL_ITEM (app->tb_item_playlist_commit), -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_separator, -1);
-    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_prev, -1);
+    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_prev, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_play, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_pause, -1);
-    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_next, -1);
+    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_next, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_stop, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_save, -1);
 
     /* Add signal lister to "Close" button */
-    g_signal_connect (G_OBJECT (tb_go), "clicked",
+    g_signal_connect (G_OBJECT (app->tb_go), "clicked",
         G_CALLBACK (callback_file_go), app);
     g_signal_connect (G_OBJECT (tb_open), "clicked",
         G_CALLBACK(callback_file_open), app);
-    g_signal_connect (G_OBJECT (tb_prev), "clicked",
+    g_signal_connect (G_OBJECT (app->tb_prev), "clicked",
         G_CALLBACK (cb_playlist_prev), app->control);
     g_signal_connect (G_OBJECT (app->tb_play), "clicked",
         G_CALLBACK (cb_playlist_play), app->control);
     g_signal_connect (G_OBJECT (app->tb_pause), "clicked",
         G_CALLBACK (cb_playlist_play), app->control);
-    g_signal_connect (G_OBJECT (tb_next), "clicked",
+    g_signal_connect (G_OBJECT (app->tb_next), "clicked",
         G_CALLBACK (cb_playlist_next), app->control);
     g_signal_connect (G_OBJECT (app->tb_stop), "clicked",
         G_CALLBACK (cb_playlist_stop), app->control);
@@ -389,143 +377,74 @@ static void create_toolbar (Application * app) {
             GTK_TOOLBAR(app->main_toolbar));
 }
 
-static void mainMenuShow (GtkWidget *w, Application *app) {
-    (void)w;
-    app_set_suspend (app, true);
-}
-
-static void mainMenuHide (GtkWidget *w, Application *app) {
-    (void)w;
-    app_set_suspend (app, false);
+static GtkWidget *makeMenuButton (const char *text) {
+    GtkWidget *item = hildon_gtk_button_new (HILDON_SIZE_AUTO);
+    gtk_button_set_label (GTK_BUTTON (item), text);
+    return item;
 }
 
 /* Create the menu items needed for the main view */
 static void create_menu (Application * app) {
     /* Create needed variables */
-    GtkMenu *main_menu;
+    HildonAppMenu *main_menu;
     GtkWidget *item_new;
     GtkWidget *item_open;
-    GtkWidget *item_export_xml;
-    GtkWidget *item_export_m3u;
-    GtkWidget *menu_playlist;
-    GtkWidget *menu_generators;
-    GtkWidget *menu_players;
     GtkWidget *item_close;
     GtkWidget *item_playlist;
-    GtkWidget *item_playlist_show;
     GtkWidget *item_playlist_generators;
     GtkWidget *item_players;
 
-    /* Get the menu from view */
-    main_menu = GTK_MENU (gtk_menu_new ());
+    main_menu = HILDON_APP_MENU (hildon_app_menu_new ());
 
-    /* Create new submenu for "Others" */
-    menu_playlist = gtk_menu_new ();
-    menu_generators = gtk_menu_new ();
-    menu_players = gtk_menu_new ();
+    item_new = makeMenuButton ("New");
+    item_open = makeMenuButton ("Open...");
+    item_playlist = makeMenuButton ("Playlist Options...");
+    item_playlist_generators = makeMenuButton("Generators...");
+    app->menu_item_playlist_copy = makeMenuButton("Copy");
+    app->menu_item_playlist_paste = makeMenuButton("Paste");
+    app->menu_item_playlist_paste_in_group = makeMenuButton ("Paste in new Group");
+    app->menu_item_playlist_cut = makeMenuButton("Cut");
+    item_close = makeMenuButton ("Close");
+    item_players = makeMenuButton ("Choose Player...");
 
-    /* Create menu items */
-    item_new = gtk_menu_item_new_with_label ("New");
-    item_open = gtk_menu_item_new_with_label ("Open");
-    item_export_xml = gtk_menu_item_new_with_label ("Export XML");
-    item_export_m3u = gtk_menu_item_new_with_label ("Export m3u");
-    /* item_check = gtk_check_menu_item_new_with_label ("Check");*/
-    item_playlist = gtk_menu_item_new_with_label ("Playlist");
-    item_playlist_show = gtk_check_menu_item_new_with_label ("Show");
-    item_playlist_generators = gtk_menu_item_new_with_label("Generators");
-    app->menu_item_playlist_copy = gtk_menu_item_new_with_label("Copy");
-    app->menu_item_playlist_paste = gtk_menu_item_new_with_label("Paste");
-    app->menu_item_playlist_paste_in_group = gtk_menu_item_new_with_label ("Paste in new Group");
-    app->menu_item_playlist_cut = gtk_menu_item_new_with_label("Cut");
-    app->menu_item_playlist_title = gtk_menu_item_new_with_label("Change Title");
-    app->menu_item_playlist_showall = gtk_check_menu_item_new_with_label ("Show All");
-    app->menu_item_playlist_edit = gtk_check_menu_item_new_with_label ("Edit");
-    item_close = gtk_menu_item_new_with_label ("Close");
-    item_players = gtk_menu_item_new_with_label ("Player");
-    app->menu_item_media_server = gtk_radio_menu_item_new_with_label (NULL, "Osso Media Server");
-    app->menu_item_mplayer = gtk_radio_menu_item_new_with_label_from_widget(
-            GTK_RADIO_MENU_ITEM (app->menu_item_media_server), "MPlayer");
-    app->menu_item_npp = gtk_radio_menu_item_new_with_label_from_widget(
-            GTK_RADIO_MENU_ITEM (app->menu_item_media_server), "Flash");
-    app->menu_item_mplayer_vo = gtk_check_menu_item_new_with_label(
-            "Use omapfb with MPlayer");
-
-    /* Add menu items to right menus */
-    gtk_menu_append (main_menu, item_new);
-    gtk_menu_append (main_menu, item_open);
-    gtk_menu_append (main_menu, item_playlist_generators);
-    gtk_menu_append (main_menu, item_playlist);
-    gtk_menu_append (main_menu, item_players);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_copy);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_paste);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_paste_in_group);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_cut);
-    gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
-    gtk_menu_append (menu_playlist, item_export_xml);
-    gtk_menu_append (menu_playlist, item_export_m3u);
-    gtk_menu_append (menu_playlist, gtk_separator_menu_item_new ());
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_title);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_showall);
-    gtk_menu_append (menu_playlist, app->menu_item_playlist_edit);
-    gtk_menu_append (menu_players, app->menu_item_media_server);
-    gtk_menu_append (menu_players, app->menu_item_mplayer);
-    gtk_menu_append (menu_players, app->menu_item_npp);
-    gtk_menu_append (menu_players, gtk_separator_menu_item_new ());
-    gtk_menu_append (menu_players, app->menu_item_mplayer_vo);
-    gtk_menu_append( main_menu, item_close );
-
-    /* Add others submenu to the "Others" item */
-    gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_playlist), menu_playlist);
-    gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_playlist_generators), menu_generators);
-    gtk_menu_item_set_submenu (GTK_MENU_ITEM (item_players), menu_players);
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_new));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_open));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_playlist_generators));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_playlist));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (item_players));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_copy));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste_in_group));
+    hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_cut));
+    hildon_app_menu_append( main_menu, GTK_BUTTON (item_close ));
 
     /* Attach the callback functions to the activate signal */
-    g_signal_connect (G_OBJECT (item_new), "activate",
+    g_signal_connect_after (G_OBJECT (item_new), "clicked",
         G_CALLBACK (callback_file_new), app);
-    g_signal_connect( G_OBJECT( item_close ), "activate",
+    g_signal_connect_after( G_OBJECT( item_close ), "clicked",
         GTK_SIGNAL_FUNC (cb_mainview_close), app);
-    g_signal_connect (G_OBJECT (item_open), "activate",
+    g_signal_connect_after (G_OBJECT (item_open), "clicked",
         GTK_SIGNAL_FUNC (callback_file_open), app);
-    g_signal_connect (G_OBJECT (item_export_xml), "activate",
-        GTK_SIGNAL_FUNC (callback_file_export_xml), app);
-    g_signal_connect (G_OBJECT (item_export_m3u), "activate",
-        GTK_SIGNAL_FUNC (callback_file_export_m3u), app);
-    g_signal_connect (G_OBJECT (item_playlist), "activate",
-        GTK_SIGNAL_FUNC (cb_playlistMenuActivate), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_copy), "activate",
+    g_signal_connect_after (G_OBJECT (item_playlist), "clicked",
+        GTK_SIGNAL_FUNC (playlistMenuActivate), app);
+    g_signal_connect_after (G_OBJECT (app->menu_item_playlist_copy), "clicked",
         GTK_SIGNAL_FUNC (cb_playlistCopy), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_paste), "activate",
+    g_signal_connect_after (G_OBJECT (app->menu_item_playlist_paste), "clicked",
         GTK_SIGNAL_FUNC (cb_playlistPaste), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_paste_in_group), "activate",
+    g_signal_connect_after (G_OBJECT (app->menu_item_playlist_paste_in_group), "clicked",
         GTK_SIGNAL_FUNC (cb_playlistPasteInNewGroup), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_cut), "activate",
+    g_signal_connect_after (G_OBJECT (app->menu_item_playlist_cut), "clicked",
         GTK_SIGNAL_FUNC (cb_playlistCut), app);
-    g_signal_connect (G_OBJECT (item_playlist_generators), "activate",
+    g_signal_connect_after (G_OBJECT (item_playlist_generators), "clicked",
         GTK_SIGNAL_FUNC (generatorMenuActivate), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_title), "activate",
-        GTK_SIGNAL_FUNC (cb_playlistTitle), app);
-    g_signal_connect (G_OBJECT (item_playlist_show), "toggled",
-        GTK_SIGNAL_FUNC (togglePlaylistShow), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_showall), "toggled",
-        GTK_SIGNAL_FUNC (togglePlaylistShowAll), app);
-    g_signal_connect (G_OBJECT (app->menu_item_playlist_edit), "toggled",
-        GTK_SIGNAL_FUNC (togglePlaylistEdit), app);
-    g_signal_connect (G_OBJECT (app->menu_item_media_server), "toggled",
-        GTK_SIGNAL_FUNC (toggleMediaServer), app);
-    g_signal_connect (G_OBJECT (app->menu_item_mplayer), "toggled",
-        GTK_SIGNAL_FUNC (toggleMediaServer), app);
-    g_signal_connect (G_OBJECT (app->menu_item_npp), "toggled",
-        GTK_SIGNAL_FUNC (toggleMediaServer), app);
-    g_signal_connect (G_OBJECT (app->menu_item_mplayer_vo), "toggled",
-        GTK_SIGNAL_FUNC (toggleVO), app);
+    g_signal_connect_after (G_OBJECT (item_players), "clicked",
+        GTK_SIGNAL_FUNC (playerMenuActivate), app);
 
-    g_signal_connect (G_OBJECT (main_menu), "show",
-        GTK_SIGNAL_FUNC (mainMenuShow), app);
-    g_signal_connect (G_OBJECT (main_menu), "hide",
-        GTK_SIGNAL_FUNC (mainMenuHide), app);
+    g_signal_connect (G_OBJECT (main_menu), "map-event",
+        GTK_SIGNAL_FUNC (cb_playlistMenuActivate), app);
     /* Make all menu widgets visible */
     gtk_widget_show_all (GTK_WIDGET (main_menu));
-    hildon_program_set_common_menu (HILDON_PROGRAM (app->program), main_menu);
+    hildon_window_set_app_menu (HILDON_WINDOW (app->window), main_menu);
 }
 
 /* Callback for normal D-BUS messages */
@@ -569,7 +488,11 @@ static void sig_abort(int i) {
     if (!n)
         return;
     backtrace_symbols_fd (trace, n, 2);
-    exit(0);
+    _exit(0);
+}
+
+void cbPluginRemoved (GtkSocket *socket, Application *app) {
+    fprintf (stderr, "plugin removed\n");
 }
 
 /* Callback for exit D-BUS event */
@@ -595,7 +518,6 @@ int main (int argc, char* argv[]) {
     PangoContext *pango_cxt;
     PangoFontDescription *pfd;
     Application *app;
-    int i;
 
     g_thread_init (NULL);
     /* Create needed variables */
@@ -623,11 +545,7 @@ int main (int argc, char* argv[]) {
     gtk_init (&argc, &argv);
 
     /* Create the hildon application and setup the title */
-#ifdef BUILD_BORA
-    program = HILDON_PROGRAM (hildon_program_new());
-#else
     program = HILDON_PROGRAM (hildon_program_get_instance());
-#endif
     app->program = G_OBJECT (program);
 
     /*app->osso_context = osso_initialize ("kmplayer", "0.1", FALSE, NULL);
@@ -638,6 +556,7 @@ int main (int argc, char* argv[]) {
     /* Create HildonAppView and set it to HildonApp */
     main_window = HILDON_WINDOW (hildon_stackable_window_new ());
     app->window = GTK_WINDOW (main_window);
+    hildon_program_add_window (program, main_window);
 
     /* Add example label to appview */
     app->hsplit_view = GTK_PANED (gtk_hpaned_new ());
@@ -650,7 +569,13 @@ int main (int argc, char* argv[]) {
     app->isplit_view = gtk_vbox_new (false, 0);
     gtk_paned_pack1 (app->hsplit_view, GTK_WIDGET (scroll_window), true, false);
     gtk_paned_pack2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view), true, false);
-    app->view_area = gtk_drawing_area_new ();
+    app->view_base = gtk_alignment_new (0, 0, 1, 1);
+    app->view_area = gtk_fixed_new ();
+    app->video_socket = gtk_socket_new ();
+    gtk_fixed_set_has_window (GTK_FIXED (app->view_area), TRUE);
+    gtk_widget_set_size_request (app->video_socket, 50, 50);
+    gtk_fixed_put (GTK_FIXED (app->view_area), app->video_socket, -60, -60);
+    gtk_container_add (GTK_CONTAINER (app->view_base), app->view_area);
     _app_setup_window (app->view_area, app);
     g_signal_connect (app->program, "notify::is-topmost",
         GTK_SIGNAL_FUNC (programTopMost), app);
@@ -660,7 +585,11 @@ int main (int argc, char* argv[]) {
         GTK_SIGNAL_FUNC (cb_window_expose), app);
     g_signal_connect (G_OBJECT (main_window), "notify::is-topmost",
         GTK_SIGNAL_FUNC (windowTopMost), app);
-    gtk_paned_add1 (app->vsplit_view, app->view_area);
+    g_signal_connect (G_OBJECT (app->video_socket), "plug-added",
+            GTK_SIGNAL_FUNC (cbPluginAdded), app);
+    g_signal_connect (G_OBJECT (app->video_socket), "plug-removed",
+            GTK_SIGNAL_FUNC (cbPluginRemoved), app);
+    gtk_paned_add1 (app->vsplit_view, app->view_base);
     app->infopanel_view = gtk_text_view_new ();
     app->info_viewport = gtk_scrolled_window_new (0L, 0l);
     app->html_viewport = gtk_scrolled_window_new (0L, 0l);
@@ -692,7 +621,6 @@ int main (int argc, char* argv[]) {
     /* Create menu for view */
     create_menu (app);
     create_toolbar (app);
-    hildon_program_add_window (program, main_window);
 
     g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN(app->location_bar))),
             "focus-in-event", GTK_SIGNAL_FUNC (locationbarGainFocus), app);
