@@ -60,11 +60,14 @@ typedef struct _Application {
     GtkWindow *window_fullscreen;
     osso_context_t *osso_context;
     GtkWidget * main_toolbar;
+    GtkToolItem * tb_prev;
     GtkToolItem * tb_play;
     GtkToolItem * tb_pause;
+    GtkToolItem * tb_next;
     GtkToolItem * tb_save;
     GtkToolItem * tb_stop;
     GtkToolItem * tb_location;
+    GtkToolItem * tb_go;
     GtkToolItem * tb_progress;
     GtkWidget * playlist_view;
     GtkWidget * infopanel_view;
@@ -72,18 +75,12 @@ typedef struct _Application {
     GtkWidget * html_infopanel_view;
     GtkWidget * html_viewport;
     GtkWidget * view_area;
-    GtkWidget * view_area_fullscreen;
+    GtkWidget * view_base;
+    GtkWidget * video_socket;
     GtkWidget * menu_item_playlist_copy;
     GtkWidget * menu_item_playlist_paste;
     GtkWidget * menu_item_playlist_paste_in_group;
     GtkWidget * menu_item_playlist_cut;
-    GtkWidget * menu_item_playlist_showall;
-    GtkWidget * menu_item_playlist_edit;
-    GtkWidget * menu_item_playlist_title;
-    GtkWidget * menu_item_media_server;
-    GtkWidget * menu_item_mplayer;
-    GtkWidget * menu_item_npp;
-    GtkWidget * menu_item_mplayer_vo;
     GtkWidget * tb_item_playlist_commit;
     GtkWidget * location_bar;
     GtkWidget * progress_bar;
@@ -102,13 +99,10 @@ typedef struct _Application {
     int playing;
 } Application;
 
-
 GtkWidget * createTreeView (Application * app);
-void togglePlaylistShow (GtkCheckMenuItem *checkmenuitem, Application * app);
-void togglePlaylistShowAll (GtkCheckMenuItem *checkmenuitem, Application * app);
-void togglePlaylistEdit (GtkCheckMenuItem *checkmenuitem, Application * app);
-void toggleMediaServer (GtkCheckMenuItem *radio, Application * app);
-void toggleVO (GtkCheckMenuItem *check, Application * app);
+void togglePlaylistShowAll (Application *app);
+void togglePlaylistEdit (Application *app);
+void playerMenuActivate (GtkMenuItem *item, Application *app);
 gboolean cb_mainview_delete (GtkObject *w, GdkEvent *event, Application *app);
 void cb_mainview_close (GtkObject *w, Application *app);
 gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app);
@@ -119,13 +113,14 @@ void cb_view_area_realized (GtkWidget *widget, Application * app);
 void cb_view_area_expose (GtkWidget *widget, GdkEventExpose *event, Application * app);
 void cb_view_area_configure (GtkWidget *widget, GdkEventConfigure *event, Application * app);
 void cb_view_area_button_press (GtkWidget *widget, GdkEventButton *event, Application * app);
-void cb_playlistMenuActivate (GtkButton * button, Application * app);
+void cb_playlistMenuActivate (GtkWidget *w, GdkEvent *e, Application *app);
 void generatorMenuActivate (GtkMenuItem *item, Application * app);
+void playlistMenuActivate (GtkMenuItem *item, Application * app);
 void cb_playlistCopy (GtkButton * button, Application * app);
 void cb_playlistPaste (GtkButton * button, Application * app);
 void cb_playlistPasteInNewGroup (GtkButton * button, Application * app);
 void cb_playlistCut (GtkButton * button, Application * app);
-void cb_playlistTitle (GtkButton * button, Application * app);
+void cb_playlistTitle (Application * app);
 void cb_playlist_prev (GtkButton * button, void *ctr);
 void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
@@ -136,6 +131,7 @@ void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
 gboolean cbViewAreaFullscreenMapped (GtkWidget *w, GdkEvent *, Application *a);
 void cbViewAreaFullscreenUnmapped (GtkWidget *w, Application *a);
+void cbPluginAdded (GtkSocket *socket, Application *app);
 void cb_fullscreen_destoyed (GtkObject *o, Application *app);
 
 void save_locationbar (Application * app);
