@@ -23,7 +23,7 @@
 using namespace KMPlayer;
 
 static String getAsxAttribute (Element * e, const String & attr) {
-    for (Attribute *a = e->attributes ()->first (); a; a = a->nextSibling ())
+    for (Attribute *a = e->attributes ().first (); a; a = a->nextSibling ())
         if (attr == a->name ().toString ().lower ())
             return a->value ();
     return String ();
