@@ -11,13 +11,10 @@
 extern "C" {
 #include <gtkhtml/gtkhtml.h>
 }
-#ifdef BUILD_BORA
-# include <hildon-widgets/gtk-infoprint.h>
-# include <hildon-widgets/hildon-seekbar.h>
-#else
-# include <hildon/hildon-banner.h>
-# include <hildon/hildon-seekbar.h>
-#endif
+#include <hildon/hildon-banner.h>
+#include <hildon/hildon-seekbar.h>
+#include <hildon/hildon-touch-selector.h>
+#include <hildon/hildon-picker-dialog.h>
 //#include <gdk/gdk.h>
 //#include <pango/pango-font.h>
 
@@ -142,13 +139,14 @@ void Control::init () {
     downloader = new Downloader (this, m_app);
     String p = m_config->readEntry (GCONF_KEY_PLAYER, "osso-media-server");
     setProcess ((const char *) p);
+    selected_player = p;
 
-    if (use_xvideo)
+    /*if (use_xvideo)
         use_xvideo = !m_config->readNumEntry (GCONF_KEY_VO, 0);
     setUseXVideo (use_xvideo);
     if (!use_xvideo)
         gtk_check_menu_item_set_active (
-                GTK_CHECK_MENU_ITEM (m_app->menu_item_mplayer_vo), true);
+                GTK_CHECK_MENU_ITEM (m_app->menu_item_mplayer_vo), true);*/
 
     GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
     addTree (m_app, 0L, //gdk_pixbuf_new_from_xpm_data((const char**)www_xpm));
@@ -399,10 +397,6 @@ ViewArea *Control::viewArea () const {
     return (ViewArea *)m_app->viewarea;
 }
 
-unsigned long Control::videoOutput () const {
-    return GDK_DRAWABLE_XID (GDK_DRAWABLE (VIEWAREA (m_app)->videoWindow ()));
-}
-
 void Control::playCurrent () {
     String url = currentMrl ();
     // set title url;
@@ -429,8 +423,7 @@ void Control::playCurrent () {
         ;//playlist_data->current->undefer ();
     } else if (m_process->state () == Process::NotRunning) {
         //debugLog () << "playCurrent set ready" << endl;
-        m_process->ready (GDK_DRAWABLE_XID (GDK_DRAWABLE (
-                        VIEWAREA(m_app)->videoWindow ())));
+        m_process->ready (VIEWAREA (m_app)->videoXId ());
     } else if (!playlist_data->current->active ()) {
         playlist_data->current->activate ();
         updateViewAreaSizes ();
@@ -517,28 +510,25 @@ bool Control::requestPlayURL (Mrl *mrl) {
 }
 
 bool Control::setProcess (const char *pname) {
-    GtkWidget *menu;
     Process *old_process = m_process;
     if (!strcmp (pname, mplayer->name ())) {
         m_process = mplayer;
-        menu = m_app->menu_item_mplayer;
 #ifdef __ARMEL__
     } else if (!strcmp (pname, npp->name ())) {
         m_process = npp;
-        menu = m_app->menu_item_npp;
 #endif
     } else {
         m_process = media_server;
-        menu = m_app->menu_item_media_server;
     }
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu), true);
+    selected_player = m_process->name ();
+
     if (old_process) {
         if (old_process == m_process)
             old_process->stop ();
         else
             old_process->quit ();
     }
-    setUseXVideo (use_xvideo);
+    //setUseXVideo (use_xvideo);
 }
 
 bool Control::setProcess (Mrl *mrl) {
@@ -684,31 +674,13 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
 }
 
 void Control::updateViewAreaSizes () {
-    if (!m_process || !VIEWAREA(m_app)->videoWindow ())
+    if (!m_process || !VIEWAREA(m_app)->videoXId ())
         return;
     VIEWAREA(m_app)->resizeEvent();
     IRect video_rect = VIEWAREA(m_app)->videoGeometry ();
     int x = video_rect.x ();
     int y = video_rect.y ();
-#ifdef __ARMEL__
-    if (process () == npp) {
-        m_process->setVideoWindow (x, y,
-                video_rect.width (), video_rect.height ());
-    } else
-#endif
-    {
-        for (GdkWindow * win = gdk_window_get_parent (
-                    VIEWAREA(m_app)->videoWindow ());
-                win;
-                win = gdk_window_get_parent (win)) {
-            int x1, y1;
-            gdk_window_get_position (win, &x1, &y1);
-            x += x1;
-            y += y1;
-        }
-    }
-    m_process->setVideoWindow (x, y,
-            video_rect.width (), video_rect.height ());
+    m_process->setVideoWindow (x, y, video_rect.width (), video_rect.height ());
 }
 
 void Control::updatePlaylistView (bool force) {
@@ -905,9 +877,11 @@ void Control::setLength (int len) {
     hildon_seekbar_set_fraction (HILDON_SEEKBAR (m_app->progress_bar), len);
     if (len > 50) {
         gtk_widget_hide (GTK_WIDGET (m_app->tb_location));
+        gtk_widget_hide (GTK_WIDGET (m_app->tb_go));
         gtk_widget_show (GTK_WIDGET (m_app->tb_progress));
     } else {
         gtk_widget_show (GTK_WIDGET (m_app->tb_location));
+        gtk_widget_show (GTK_WIDGET (m_app->tb_go));
         gtk_widget_hide (GTK_WIDGET (m_app->tb_progress));
     }
 }
@@ -945,7 +919,7 @@ Application *app_new () {
     memset (app, 0, sizeof (Application));
     app->control = new Control (app);
     StringPool::init();
-    app->viewarea = new ViewArea;
+    app->viewarea = new ViewArea (app);
     app->top_most_window = true;
     return app;
 }
@@ -1026,6 +1000,14 @@ void app_set_info_content (Application *app, const char *s, bool plaintext) {
     }
 }
 
+void cbPluginAdded (GtkSocket *socket, Application *app) {
+#ifdef __ARMEL__
+    Control *ctr = CONTROL(app);
+    debugLog () << "plugin embedded\n";
+    ((NpPlayer *)ctr->npp)->pluginEmbedded ();
+#endif
+}
+
 void cb_playlist_prev (GtkButton * button, void *p) {
     Control *ctr = (Control *)p;
     if (ctr->playlist_data->current &&
@@ -1264,29 +1246,6 @@ void progressValueChanged(GtkWidget *w, Application * app) {
     }
 }
 
-void toggleMediaServer (GtkCheckMenuItem *radio, Application *app) {
-    if (!gtk_check_menu_item_get_active (radio))
-        return;
-    Process *p;
-    if (radio == GTK_CHECK_MENU_ITEM (app->menu_item_media_server))
-        p = CONTROL(app)->media_server;
-#ifdef __ARMEL__
-    else if (radio == GTK_CHECK_MENU_ITEM (app->menu_item_npp))
-        p = CONTROL(app)->npp;
-#endif
-    else
-        p = CONTROL(app)->mplayer;
-    CONTROL(app)->setProcess (p->name ());
-#ifdef __ARMEL__
-    if (p != CONTROL(app)->npp)
-#endif
-        CONTROL(app)->m_config->writeEntry(GCONF_KEY_PLAYER, String(p->name()));
-}
-
-void toggleVO (GtkCheckMenuItem *chk, Application *app) {
-    CONTROL(app)->setUseXVideo (!gtk_check_menu_item_get_active (chk));
-}
-
 void app_set_suspend (Application *a, bool suspend) {
     PlayListData *pd = CONTROL(a)->playlist_data;
     if (pd->document &&
@@ -1362,23 +1321,63 @@ void save_locationbar (Application *app) {
     }
 }
 
-static void generatorActivate (GtkMenuItem *item, Control *ctrl) {
-    GList *lst = gtk_container_get_children (
-            GTK_CONTAINER (gtk_widget_get_parent (GTK_WIDGET (item))));
-    NodeStoreItem *store = ctrl->generators.first ();
-    for (GList *l = lst; store && l; l = l->next) {
-        if (GTK_MENU_ITEM (l->data) == item) {
-            if (ctrl->current_generator && ctrl->current_generator->active ())
-                ctrl->current_generator->deactivate ();
-            ctrl->current_generator = store->data;
-            store->data->activate ();
-        }
-        store = store->nextSibling ();
+static void
+playerResponse (GtkDialog *dialog, gint response, gpointer data) {
+    if (response == GTK_RESPONSE_OK) {
+        Control *ctrl = (Control *) data;
+        HildonTouchSelector *sel = hildon_picker_dialog_get_selector (
+                HILDON_PICKER_DIALOG (dialog));
+
+        ctrl->selected_player = hildon_touch_selector_get_current_text (sel);
     }
-    g_list_free (lst);
 }
 
-static void getGenerators (GtkWidget *menu, Control *ctrl, const String &dir) {
+void playerMenuActivate (GtkMenuItem *item, Application *app) {
+    Control *ctrl = CONTROL(app);
+    GtkWidget *dialog = hildon_picker_dialog_new (app->window);
+    GtkWidget *selector = hildon_touch_selector_new_text();
+    String player = ctrl->selected_player;
+    int idx = 0;
+
+    hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (dialog),
+            HILDON_TOUCH_SELECTOR (selector));
+    g_signal_connect (G_OBJECT (dialog), "response",
+            G_CALLBACK (playerResponse), ctrl);
+    hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+            ctrl->media_server->name ());
+    hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+            ctrl->mplayer->name ());
+    if (player == ctrl->mplayer->name ())
+        idx = 1;
+#ifdef __ARMEL__
+    hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+            ctrl->npp->name ());
+    if (player == ctrl->npp->name ())
+        idx = 2;
+#endif
+    hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, idx);
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+
+    if (player != ctrl->selected_player) {
+        Process *p;
+        if (ctrl->selected_player == ctrl->media_server->name ())
+            p = ctrl->media_server;
+#ifdef __ARMEL__
+        else if (ctrl->selected_player == ctrl->npp->name ())
+            p = ctrl->npp;
+#endif
+        else
+            p = ctrl->mplayer;
+        ctrl->setProcess (p->name ());
+#ifdef __ARMEL__
+        if (p != ctrl->npp)
+#endif
+            ctrl->m_config->writeEntry(GCONF_KEY_PLAYER, String(p->name()));
+    }
+}
+
+static void getGenerators (Control *ctrl, const String &dir) {
     GDir *gdir = g_dir_open ((const char *) dir, 0, NULL);
     if (gdir) {
         const gchar *file = g_dir_read_name (gdir);
@@ -1388,15 +1387,11 @@ static void getGenerators (GtkWidget *menu, Control *ctrl, const String &dir) {
             gen->readFromFile (dir + Char ('/') + file);
             Node *n = gen->firstChild ();
             if (n && n->isElementNode ()) {
-                String name = static_cast <Element *> (n)->getAttribute (
+                String txt = static_cast <Element *> (n)->getAttribute (
                         StringPool::attr_name);
-                if (name.isEmpty ())
-                    name = file;
-                GtkWidget *item = gtk_menu_item_new_with_label (name);
-                gtk_menu_append (menu, item);
-                debugLog() << name << endl;
-                g_signal_connect (G_OBJECT (item), "activate",
-                                G_CALLBACK (generatorActivate), ctrl);
+                if (txt.isEmpty ())
+                    txt = file;
+                gen->setAttribute (StringPool::attr_name, txt);
                 ctrl->generators.append (new NodeStoreItem (doc));
             } else {
                 gen->dispose ();
@@ -1407,16 +1402,118 @@ static void getGenerators (GtkWidget *menu, Control *ctrl, const String &dir) {
     }
 }
 
+static void
+generatorResponse (GtkDialog *dialog, gint response, gpointer data) {
+    Control *ctrl = (Control *) data;
+    HildonTouchSelector *sel = hildon_picker_dialog_get_selector (
+            HILDON_PICKER_DIALOG (dialog));
+
+    if (response == GTK_RESPONSE_OK) {
+        gchar *selection = hildon_touch_selector_get_current_text (sel);
+        for (NodeStoreItem *s = ctrl->generators.first(); s; s = s->nextSibling()) {
+            String txt = static_cast <Element *> (s->data.ptr())->getAttribute (
+                    StringPool::attr_name);
+            if (txt == selection) {
+                ctrl->current_generator = s->data;
+                return;
+            }
+        }
+    }
+    ctrl->current_generator = NULL;
+}
+
 void generatorMenuActivate (GtkMenuItem *item, Application *app) {
     Control *ctrl = CONTROL(app);
-    if (ctrl->generators.first ())
-        return;
+    GtkWidget *dialog = hildon_picker_dialog_new (app->window);
+    GtkWidget *selector = hildon_touch_selector_new_text();
 
-    GtkWidget *menu = gtk_menu_item_get_submenu (item);
-    getGenerators (menu, ctrl, "/usr/share/applications/kmplayer/generators");
-    getGenerators (menu, ctrl, ctrl->data_dir + "/generators");
-    gtk_widget_show_all (menu);
+    hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (dialog),
+            HILDON_TOUCH_SELECTOR (selector));
+    g_signal_connect (G_OBJECT (dialog), "response",
+            G_CALLBACK (generatorResponse), ctrl);
+
+    if (!ctrl->generators.first ()) {
+        getGenerators (ctrl, "/usr/share/applications/kmplayer/generators");
+        getGenerators (ctrl, ctrl->data_dir + "/generators");
+    } else if (ctrl->current_generator) {
+        if (ctrl->current_generator->active ())
+            ctrl->current_generator->deactivate ();
+        ctrl->current_generator = NULL;
+    }
+
+    for (NodeStoreItem *s = ctrl->generators.first(); s; s = s->nextSibling()) {
+        String txt = static_cast <Element *> (s->data.ptr ())->getAttribute (
+                StringPool::attr_name);
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                                txt);
+    }
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+
+    if (ctrl->current_generator)
+        ctrl->current_generator->activate ();
 }
+
+static void
+playlistResponse (GtkDialog *dialog, gint response, gpointer data) {
+    if (response == GTK_RESPONSE_OK) {
+        Control *ctrl = (Control *) data;
+        HildonTouchSelector *sel = hildon_picker_dialog_get_selector (
+                HILDON_PICKER_DIALOG (dialog));
+        *(int *) data = hildon_touch_selector_get_active (
+                HILDON_TOUCH_SELECTOR (sel), 0);
+    } else {
+        *(int *) data = -1;
+    }
+}
+
+void playlistMenuActivate (GtkMenuItem *item, Application *app) {
+    Control *ctrl = CONTROL(app);
+    if (ctrl->current_selected) {
+        GtkWidget *dialog = hildon_picker_dialog_new (app->window);
+        GtkWidget *selector = hildon_touch_selector_new_text();
+        int idx = 0;
+
+        hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (dialog),
+                HILDON_TOUCH_SELECTOR (selector));
+        g_signal_connect (G_OBJECT (dialog), "response",
+                G_CALLBACK (playlistResponse), &idx);
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                "Export as XML");
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                "Export as m3u");
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                "Change Title");
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                "Show all XML Nodes");
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                "Edit XML");
+        gtk_dialog_run (GTK_DIALOG (dialog));
+        gtk_widget_destroy (dialog);
+
+        switch (idx) {
+        case 0:
+            saveFile (app, true);
+            break;
+        case 1:
+            saveFile (app, false);
+            break;
+        case 2:
+            cb_playlistTitle (app);
+            break;
+        case 3:
+            togglePlaylistShowAll (app);
+            break;
+        case 4:
+            togglePlaylistEdit (app);
+            break;
+        }
+    } else {
+        hildon_banner_show_information (GTK_WIDGET (app->window), NULL,
+                "No Playlist Item Selected");
+    }
+}
+
 /*
  * TODO
 static void cb_iap (struct iap_event_t * event, void * arg) {
