@@ -72,7 +72,6 @@ public:
     String currentMrl ();
     void updatePlaylistView (bool force=false);
     ViewArea *viewArea () const;
-    unsigned long videoOutput () const;
     void addRecent (const String &url, const String &title);
     void setCurrentSelected (NodePtr node);
     /**
@@ -124,6 +123,7 @@ public:
     NodeStoreList generators;
     String cur_url;
     String data_dir;
+    String selected_player;
     Config * m_config;
     Application * m_app;
     int paint_timer;
