@@ -225,7 +225,9 @@ enum MessageType
     MsgEventStarted,
     MsgEventStopped,
     MsgMediaFinished,
+    MsgStateChanged,
     // the above messages are ordered like SMIL timing events
+    MsgMediaPrefetch,
     MsgMediaReady,
     MsgMediaUpdated,
     MsgEventPostponed,
@@ -249,7 +251,7 @@ enum RoleType
     RoleDisplay,
     RoleChildDisplay,    // Mrl*
     RoleSizer,
-    RoleReceivers,
+    RoleReceivers
 };
 
 #define MsgUnhandled ((void *) 357L)
@@ -292,13 +294,21 @@ class ConnectionList;
 extern int connection_counter;
 #endif
 
+struct VirtualVoid {
+    virtual ~VirtualVoid () {}
+};
+
 struct Connection {
     NodePtrW connectee; // the one that will, when ever, trigger the event
     NodePtrW connecter; // the one that will, when ever, receive the event
-    Connection (Node *invoker, Node*receiver);
+    Connection (Node *invoker, Node*receiver, VirtualVoid *payload);
+    ~Connection () {
+        delete payload;
 #ifdef KMPLAYER_TEST_CONNECTION
-    ~Connection () { connection_counter--; }
+        connection_counter--;
 #endif
+    }
+    VirtualVoid *payload;
     ConnectionList *list;
     Connection **link;
     Connection *prev;
@@ -314,7 +324,8 @@ public:
     ConnectionLink ();
     ~ConnectionLink ();
 
-    bool connect (Node *signaler, MessageType msg, Node *receiver);
+    bool connect (Node *signaler, MessageType msg, Node *receiver,
+            VirtualVoid *payload=NULL);
     void disconnect () const;
     void assign (const ConnectionLink *link) const;
 
@@ -393,6 +404,7 @@ public:
     String outerXML (bool inter_doc=true) const;
     virtual const char * nodeName () const;
     virtual String nodeValue () const;
+    virtual void setNodeName (const String &) {}
 
     /**
      * If this is a derived Mrl object and has a SRC attribute
