@@ -411,17 +411,6 @@ static Node *getNode (PlayListData * pld, GtkTreePath * path) {
     return node;
 }
 
-static void restoreEditMode (Application * app, PlayListData * pld) {
-    if (!pld->edit_mode && gtk_check_menu_item_get_active
-            (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_edit)))
-        gtk_check_menu_item_set_active
-            (GTK_CHECK_MENU_ITEM(app->menu_item_playlist_showall), false);
-    gtk_widget_set_sensitive
-        (GTK_WIDGET(app->menu_item_playlist_showall), !!pld->document);
-    gtk_widget_set_sensitive
-        (GTK_WIDGET(app->menu_item_playlist_edit), !!pld->document);
-}
-
 static void setInfoContent (Application *app, Node *node, bool edit_mode) {
     app_set_info_content (app, node
             ? edit_mode
@@ -451,7 +440,6 @@ void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
         GtkTreeModel * model = gtk_tree_view_get_model (treeview);
         PlayListData * pld = getListData (app, model, &iter);
-        restoreEditMode (app, pld);
         GtkTreePath* path = gtk_tree_model_get_path (model, &iter);
         gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
         Node *node = getNode (pld, path);
@@ -479,11 +467,45 @@ static gboolean delayedJump (Application *app) {
     return false;
 }
 
+static void
+setPlaylistEdit (Application *app, PlayListData *pld, bool editable) {
+    if (editable) {
+        gtk_widget_show (GTK_WIDGET (app->tb_item_playlist_commit));
+        gtk_widget_hide (GTK_WIDGET (app->tb_save));
+    } else {
+        gtk_widget_hide (GTK_WIDGET (app->tb_item_playlist_commit));
+        if (!GTK_WIDGET_VISIBLE (app->tb_stop))
+            gtk_widget_show (GTK_WIDGET (app->tb_save));
+    }
+    g_object_set (G_OBJECT (app->playlist_cell_renderer),
+            "editable", editable, 0L);
+    g_object_set (G_OBJECT (app->infopanel_view),
+            "editable", editable, "cursor-visible", editable, 0L);
+    pld->edit_mode = editable;
+    pld->updated_document = NULL;
+    gtk_paned_set_position (app->vsplit_view, editable ? 0 : VSPLIT);
+    g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+}
+
 void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
         GtkTreeViewColumn *arg2, Application * app) {
     PlayListData *pld = getListData (CONTROL(app), path);
     Node *node = getNode (pld, path);
     debugLog() << "row activated" << endl;
+
+    // click outside editable tree
+    for (PlayListData *pd = CONTROL(app)->playlist_data; pd; pd = pd->next)
+        if (pd != pld && (pd->edit_mode || pd->show_all)) {
+            pd->show_all = false;
+            if (pd->edit_mode) {
+                setPlaylistEdit (app, pd, false);
+            } else {
+                pd->updated_document = NULL;
+                g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+            }
+            break;
+        }
+
     if (gtk_tree_path_get_depth (path) != 1) {
         if (pld->id == 0 || pld->edit_mode)
             setInfoContent (app, node, pld->edit_mode);
@@ -727,7 +749,7 @@ GtkWidget * createTreeView (Application * app) {
     return view;
 }
 
-void cb_playlistMenuActivate (GtkButton * button, Application * app) {
+void cb_playlistMenuActivate (GtkWidget *, GdkEvent *, Application * app) {
     bool show_copy = false, show_paste = false, show_cut = false,
          show_title = false;
     GtkTreePath *path;
@@ -751,11 +773,21 @@ void cb_playlistMenuActivate (GtkButton * button, Application * app) {
                  node->id == id_node_html_object);
         }
     }
-    gtk_widget_set_sensitive (app->menu_item_playlist_copy, show_copy);
-    gtk_widget_set_sensitive (app->menu_item_playlist_paste, show_paste);
-    gtk_widget_set_sensitive(app->menu_item_playlist_paste_in_group,show_paste);
-    gtk_widget_set_sensitive (app->menu_item_playlist_cut, show_cut);
-    gtk_widget_set_sensitive (app->menu_item_playlist_title, show_title);
+    if (show_copy)
+        gtk_widget_show (app->menu_item_playlist_copy);
+    else
+        gtk_widget_hide (app->menu_item_playlist_copy);
+    if (show_paste) {
+        gtk_widget_show (app->menu_item_playlist_paste);
+        gtk_widget_show (app->menu_item_playlist_paste_in_group);
+    } else {
+        gtk_widget_hide (app->menu_item_playlist_paste);
+        gtk_widget_hide (app->menu_item_playlist_paste_in_group);
+    }
+    if (show_cut)
+        gtk_widget_show (app->menu_item_playlist_cut);
+    else
+        gtk_widget_hide (app->menu_item_playlist_cut);
 }
 
 void cb_playlistCopy (GtkButton * button, Application * app) {
@@ -894,7 +926,7 @@ void cb_playlistCut (GtkButton * button, Application * app) {
     }
 }
 
-void cb_playlistTitle (GtkButton *button, Application *app) {
+void cb_playlistTitle (Application *app) {
     GtkTreePath *path;
     PlayListData *pld = getListDataFromSelection (app, &path);
     if (pld) {
@@ -912,14 +944,11 @@ void cb_playlistTitle (GtkButton *button, Application *app) {
     }
 }
 
-void togglePlaylistShow (GtkCheckMenuItem *menuitem, Application * app) {
-}
-
-void togglePlaylistShowAll (GtkCheckMenuItem *menuitem, Application * app) {
+void togglePlaylistShowAll (Application *app) {
     //g_print ("togglePlaylistShowAll\n");
-    bool selected = gtk_check_menu_item_get_active (menuitem);
     PlayListData * pld = getListDataFromSelection (app);
     if (pld) {
+        bool selected = !pld->show_all;
         if (!selected && !pld->show_all) { // click outside editable tree
             for (PlayListData * pd = CONTROL(app)->playlist_data; pd; pd = pd->next)
                 if (pd->show_all) {
@@ -929,45 +958,15 @@ void togglePlaylistShowAll (GtkCheckMenuItem *menuitem, Application * app) {
         }
         pld->show_all = selected;
         pld->updated_document = NULL;
-        //gtk_widget_set_sensitive (app->menu_item_playlist_edit, selected);
-        if (pld->edit_mode && !selected)
-            gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_edit), false);
-        else
-            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+        g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
     }
 }
 
-void togglePlaylistEdit (GtkCheckMenuItem *menuitem, Application * app) {
+void togglePlaylistEdit (Application *app) {
     //g_print ("togglePlaylistEdit\n");
-    bool editable = gtk_check_menu_item_get_active (menuitem);
     PlayListData * pld = getListDataFromSelection (app);
     if (pld) {
-        if (editable) {
-            gtk_widget_show (GTK_WIDGET (app->tb_item_playlist_commit));
-            gtk_widget_hide (GTK_WIDGET (app->tb_save));
-        } else {
-            gtk_widget_hide (GTK_WIDGET (app->tb_item_playlist_commit));
-            if (!GTK_WIDGET_VISIBLE (app->tb_stop))
-                gtk_widget_show (GTK_WIDGET (app->tb_save));
-        }
-        g_object_set (G_OBJECT (app->playlist_cell_renderer),
-                "editable", editable, 0L);
-        g_object_set (G_OBJECT (app->infopanel_view),
-                "editable", editable, "cursor-visible", editable, 0L);
-        if (!editable && !pld->edit_mode) { // click outside editable tree
-            for (PlayListData * pd = CONTROL(app)->playlist_data; pd; pd = pd->next)
-                if (pd->edit_mode) {
-                    pld = pd;
-                    break;
-                }
-        }
-        pld->edit_mode = editable;
-        pld->updated_document = NULL;
-        gtk_paned_set_position (app->vsplit_view, editable ? 0 : VSPLIT);
-        if (!pld->show_all && editable)
-            gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_showall), true);
-        else
-            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+        setPlaylistEdit (app, pld, !pld->edit_mode);
         NodePtr node = pld->current;
         if (!node)
             node = pld->document;
