@@ -41,12 +41,10 @@ http://devedge-temp.mozilla.org/library/manuals/2002/plugin/1.0/
 
 #include "npplayer.h"
 
-static GtkWidget *top_widget;
 static int top_w, top_h;
-static GtkWidget *xembed;
 static Window socket_id;
-static Window parent_id;
 static int update_dimension_timer;
+static gchar *start_url;
 
 static void *browser_data;
 static NSNotify *browser_notify;
@@ -57,10 +55,11 @@ static NPObject *js_window;
 static NPObject *scriptable_peer;
 static NPSavedData *saved_data;
 static NPClass js_class;
+static NPClass window_class;
+static NPClass location_class;
 static GTree *stream_list;
 static int stream_id_counter;
 static GTree *identifiers;
-static int js_obj_counter;
 typedef struct _StreamInfo {
     NPStream np_stream;
     /*unsigned int stream_buf_pos;*/
@@ -79,7 +78,6 @@ typedef struct _StreamInfo {
 struct JsObject;
 typedef struct _JsObject {
     NPObject npobject;
-    struct _JsObject * parent;
     char * name;
 } JsObject;
 
@@ -133,7 +131,7 @@ static gboolean requestStream (void * p) {
 
 static gboolean destroyStream (void * p) {
     StreamInfo *si = (StreamInfo *) g_tree_lookup (stream_list, p);
-    print ("FIXME destroyStream\n");
+    print ("FIXME destroyStream %d\n", (int)p);
     if (si)
         browser_notify->finishStream (npp, (int)(long)p, browser_data);
     return 0; /* single shot */
@@ -180,8 +178,10 @@ static int32_t writeStream (uint32_t stream, const char *buf, uint32_t count) {
             if (sz > 0) {
                 sz = np_funcs.write (npp, &si->np_stream, si->stream_pos,
                         (int32_t) count > sz ? sz : (int32_t) count, buf);
-                if (sz < 0) /*FIXME plugin destroys stream here*/
-                    g_timeout_add (0, destroyStream, (gpointer)stream);
+                if (sz < 0) { /*FIXME plugin destroys stream here*/
+                    destroyStream ((gpointer)stream);
+                    return 0;
+                }
             } else {
                 sz = 0;
             }
@@ -221,67 +221,6 @@ static StreamInfo *addStream (const char *url, const char *mime,
 
 /*----------------%<---------------------------------------------------------*/
 
-static void createJsName (JsObject * obj, char **name, uint32_t * len) {
-    int slen = strlen (obj->name);
-    if (obj->parent) {
-        *len += slen + 1;
-        createJsName (obj->parent, name, len);
-    } else {
-        *name = (char *) nsAlloc (*len + slen + 1);
-        *(*name + *len + slen) = 0;
-        *len = 0;
-    }
-    if (obj->parent) {
-        *(*name + *len) = '.';
-        *len += 1;
-    }
-    memcpy (*name + *len, obj->name, slen);
-    *len += slen;
-}
-
-static char *nsVariant2Str (const NPVariant *value) {
-    char *str;
-    switch (value->type) {
-        case NPVariantType_String:
-            str = (char *) nsAlloc (value->value.stringValue.utf8length + 3);
-            str[0] = str[value->value.stringValue.utf8length + 1] = '\'';
-            strncpy (str + 1, value->value.stringValue.utf8characters,
-                    value->value.stringValue.utf8length);
-            str[value->value.stringValue.utf8length + 2] = 0;
-            break;
-        case NPVariantType_Int32:
-            str = (char *) nsAlloc (16);
-            snprintf (str, 15, "%d", value->value.intValue);
-            break;
-        case NPVariantType_Double:
-            str = (char *) nsAlloc (64);
-            snprintf (str, 63, "%f", value->value.doubleValue);
-            break;
-        case NPVariantType_Bool:
-            str = strdup (value->value.boolValue ? "true" : "false");
-            break;
-        case NPVariantType_Null:
-            str = strdup ("null");
-            break;
-        case NPVariantType_Object:
-            if (&js_class == value->value.objectValue->_class) {
-                JsObject *jv = (JsObject *) value->value.objectValue;
-                char *val;
-                uint32_t vlen = 0;
-                createJsName (jv, &val, &vlen);
-                str = strdup (val);
-                nsMemFree (val);
-                break;
-            } /* else fall through */
-        default:
-            str = strdup ("");
-            break;
-    }
-    return str;
-}
-
-/*----------------%<---------------------------------------------------------*/
-
 static NPObject * nsCreateObject (NPP instance, NPClass *aClass) {
     NPObject *obj;
     if (aClass && aClass->allocate)
@@ -305,7 +244,10 @@ static void nsReleaseObject (NPObject *npobj) {
     if (!obj)
         obj = scriptable_peer;
     if (! (--obj->referenceCount)) {
-        obj->_class->deallocate (obj);
+        if (obj->_class->deallocate)
+            obj->_class->deallocate (obj);
+        else
+            nsMemFree (obj);
         if (obj == scriptable_peer) {
             print ("NPN_ReleaseObject default\n");
             scriptable_peer = NULL;
@@ -368,7 +310,7 @@ static void nsStatus (NPP instance, const char* message) {
 static const char* nsUserAgent (NPP instance) {
     (void)instance;
     print ("NPN_UserAgent\n");
-    return "Mozilla/5.0 (X11; U; Linux armv6l; en-US; rv:1.9a6pre) Gecko/20080828 Firefox/3.0a1 Tablet browser 0.3.7 RX-34+RX-44+RX-48_DIABLO_5.2008.43-7";
+    return "Mozilla/5.0 (X11; U; Linux armv7l; en-US; rv:1.9.2a1pre) Gecko/20090907 Firefox/3.5 Maemo Browser 1.4.1.8 RX-51 N900";
 }
 
 static uint32 nsMemFlush (uint32 size) {
@@ -418,6 +360,7 @@ static NPError nsGetValue (NPP instance, NPNVariable variable, void *value) {
             break;
         case NPNVnetscapeWindow:
             print ("NPNVnetscapeWindow\n");
+            *(int*)value = 0;
             break;
         case NPNVjavascriptEnabledBool:
             *(int*)value = 1;
@@ -437,15 +380,15 @@ static NPError nsGetValue (NPP instance, NPNVariable variable, void *value) {
         case NPNVSupportsXEmbedBool:
             *(int*)value = 1;
             break;
-        /*case NPNVWindowNPObject:
+        case NPNVWindowNPObject:
             if (!js_window) {
-                JsObject *jo = (JsObject*) nsCreateObject (instance, &js_class);
+                JsObject *jo = (JsObject*) nsCreateObject (instance, &window_class);
                 jo->name = g_strdup ("window");
                 js_window = (NPObject *) jo;
             }
             *(NPObject**)value = nsRetainObject (js_window);
             break;
-        case NPNVPluginElementNPObject: {
+        /*case NPNVPluginElementNPObject: {
             JsObject * obj = (JsObject *) nsCreateObject (instance, &js_class);
             obj->name = g_strdup ("this");
             *(NPObject**)value = (NPObject *) obj;
@@ -484,7 +427,7 @@ static NPIdentifier nsGetStringIdentifier (const NPUTF8* name) {
     /*print ("NPN_GetStringIdentifier %s\n", name);*/
     gpointer id = g_tree_lookup (identifiers, name);
     if (!id) {
-        id = strdup (name);
+        id = g_strdup (name);
         g_tree_insert (identifiers, id, id);
     }
     return id;
@@ -510,7 +453,7 @@ static NPUTF8 * nsUTF8FromIdentifier (NPIdentifier name) {
     char *str = g_tree_lookup (identifiers, name);
     print ("NPN_UTF8FromIdentifier\n");
     if (str)
-        return (NPUTF8 *)strdup (str);
+        return (NPUTF8 *)g_strdup (str);
     return NULL;
 }
 
@@ -521,123 +464,78 @@ static int32_t nsIntFromIdentifier (NPIdentifier identifier) {
 
 static bool nsInvoke (NPP instance, NPObject * npobj, NPIdentifier method,
         const NPVariant *args, uint32_t arg_count, NPVariant *result) {
-    (void)instance;
     NPObject *obj = npobj;
+    (void)instance;
     if (!obj) {
         if (!scriptable_peer &&
             NPERR_NO_ERROR != np_funcs.getvalue ((void*)npp,
                 NPPVpluginScriptableNPObject, (void*)&scriptable_peer))
-            return NPERR_INVALID_PARAM;
+            return false;
         obj = scriptable_peer;
     }
     /*print ("NPN_Invoke %s\n", id);*/
-    return obj->_class->invoke (obj, method, args, arg_count, result);
+    if (obj->_class->invoke)
+        return obj->_class->invoke (obj, method, args, arg_count, result);
+    return false;
 }
 
 static bool nsInvokeDefault (NPP instance, NPObject * npobj,
         const NPVariant * args, uint32_t arg_count, NPVariant * result) {
     (void)instance;
-    return npobj->_class->invokeDefault (npobj,args, arg_count, result);
+    if (npobj->_class->invokeDefault)
+        return npobj->_class->invokeDefault (npobj,args, arg_count, result);
+    return false;
 }
 
-static bool doEvaluate (NPP instance, NPObject * npobj, NPString * script,
-        NPVariant * result) {
-    char * this_var;
-    char * this_var_type;
-    char * this_var_string;
-    char * jsscript;
-    (void) npobj; /*FIXME scope, search npobj window*/
-    print ("NPN_Evaluate:");
-
-    /* assign to a js variable */
-    this_var = (char *) nsAlloc (64);
-    sprintf (this_var, "this.__kmplayer__obj_%d", js_obj_counter);
-
-    jsscript = (char *) nsAlloc (strlen (this_var) + script->utf8length + 3);
-    sprintf (jsscript, "%s=%s;", this_var, script->utf8characters);
-    this_var_string = browser_notify->evaluate (jsscript, browser_data);
-    nsMemFree (jsscript);
-
-    if (this_var_string) {
-        /* get type of js this_var */
-        jsscript = (char *) nsAlloc (strlen (this_var) + 9);
-        sprintf (jsscript, "typeof %s;", this_var);
-        this_var_type = browser_notify->evaluate (jsscript, browser_data);
-        nsMemFree (jsscript);
-
-        if (this_var_type) {
-            if (!strcasecmp (this_var_type, "undefined")) {
-                result->type = NPVariantType_Null;
-            } else if (!strcasecmp (this_var_type, "object")) {
-                JsObject *jo = (JsObject *)nsCreateObject (instance, &js_class);
-                js_obj_counter++;
-                result->type = NPVariantType_Object;
-                jo->name = g_strdup (this_var);
-                result->value.objectValue = (NPObject *)jo;
-            } else { /* FIXME numbers/void/undefined*/
-                result->type = NPVariantType_String;
-                result->value.stringValue.utf8characters =
-                    g_strdup (this_var_string);
-                result->value.stringValue.utf8length = strlen (this_var_string);
-            }
-            g_free (this_var_type);
-        }
-        g_free (this_var_string);
-    } else {
-        print ("   => error\n");
-        return false;
-    }
-    nsMemFree (this_var);
-
+static bool createUndefined (NPVariant *result) {
+    result->type = NPVariantType_String;
+    result->value.stringValue.utf8characters = g_strdup ("undefined");
+    result->value.stringValue.utf8length = 9;
     return true;
 }
 
 static bool nsEvaluate (NPP instance, NPObject * npobj, NPString * script,
         NPVariant * result) {
-    NPString str;
-    char *jsscript;
-    char *escaped;
-    bool res;
-
-    escaped = g_strescape (script->utf8characters, "");
-    str.utf8length = strlen (escaped) + 9;
-    jsscript = (char *) nsAlloc (str.utf8length);
-    sprintf (jsscript, "eval(\"%s\")", escaped);
-    str.utf8characters = jsscript;
-
-    res = doEvaluate (instance, npobj, &str, result);
-
-    nsMemFree (jsscript);
-    g_free (escaped);
-
-    return res;
+    (void) instance;
+    (void) script;
+    return createUndefined (result);
 }
 
 static bool nsGetProperty (NPP instance, NPObject * npobj,
         NPIdentifier property, NPVariant * result) {
     (void)instance;
-    return npobj->_class->getProperty (npobj, property, result);
+    if (npobj->_class->getProperty)
+        return npobj->_class->getProperty (npobj, property, result);
+    return false;
 }
 
 static bool nsSetProperty (NPP instance, NPObject * npobj,
         NPIdentifier property, const NPVariant *value) {
     (void)instance;
-    return npobj->_class->setProperty (npobj, property, value);
+    if (npobj->_class->setProperty)
+        return npobj->_class->setProperty (npobj, property, value);
+    return false;
 }
 
 static bool nsRemoveProperty (NPP inst, NPObject * npobj, NPIdentifier prop) {
     (void)inst;
-    return npobj->_class->removeProperty (npobj, prop);
+    if (npobj->_class->removeProperty)
+        return npobj->_class->removeProperty (npobj, prop);
+    return false;
 }
 
 static bool nsHasProperty (NPP instance, NPObject * npobj, NPIdentifier prop) {
     (void)instance;
-    return npobj->_class->hasProperty (npobj, prop);
+    if (npobj->_class->hasProperty)
+        return npobj->_class->hasProperty (npobj, prop);
+    return false;
 }
 
 static bool nsHasMethod (NPP instance, NPObject * npobj, NPIdentifier method) {
     (void)instance;
-    return npobj->_class->hasMethod (npobj, method);
+    if (npobj->_class->hasMethod)
+        return npobj->_class->hasMethod (npobj, method);
+    return false;
 }
 
 static void nsReleaseVariantValue (NPVariant * variant) {
@@ -676,8 +574,8 @@ static bool nsPopPopupsEnabledState (NPP instance) {
 
 /*----------------%<---------------------------------------------------------*/
 
-static NPObject * windowClassAllocate (NPP instance, NPClass *aClass) {
-    /*print ("windowClassAllocate\n");*/
+static NPObject * jsClassAllocate (NPP instance, NPClass *aClass) {
+    /*print ("jsClassAllocate\n");*/
     JsObject * jo = (JsObject *) nsAlloc (sizeof (JsObject));
     (void)instance;
     memset (jo, 0, sizeof (JsObject));
@@ -685,25 +583,9 @@ static NPObject * windowClassAllocate (NPP instance, NPClass *aClass) {
     return (NPObject *) jo;
 }
 
-static void windowClassDeallocate (NPObject *npobj) {
+static void jsClassDeallocate (NPObject *npobj) {
     JsObject *jo = (JsObject *) npobj;
-    /*print ("windowClassDeallocate\n");*/
-    if (jo->parent) {
-        nsReleaseObject ((NPObject *) jo->parent);
-    } else if (jo->name && !strncmp (jo->name, "this.__kmplayer__obj_", 21)) {
-        char *script = (char *) nsAlloc (strlen (jo->name) + 7);
-        char *result;
-        char *counter = strrchr (jo->name, '_');
-        sprintf (script, "%s=null;", jo->name);
-        result = browser_notify->evaluate (script, browser_data);
-        nsMemFree (script);
-        g_free (result);
-        if (counter) {
-            int c = strtol (counter +1, NULL, 10);
-            if (c == js_obj_counter -1)
-                js_obj_counter--; /*poor man's variable name reuse */
-        }
-    }
+    /*print ("jsClassDeallocate\n");*/
     if (jo->name)
         g_free (jo->name);
     if (npobj == js_window) {
@@ -713,131 +595,103 @@ static void windowClassDeallocate (NPObject *npobj) {
     nsMemFree (npobj);
 }
 
-static void windowClassInvalidate (NPObject *npobj) {
+static void jsClassInvalidate (NPObject *npobj) {
     (void)npobj;
-    print ("windowClassInvalidate\n");
+    print ("jsClassInvalidate\n");
 }
 
-static bool windowClassHasMethod (NPObject *npobj, NPIdentifier name) {
+static bool jsClassHasMethod (NPObject *npobj, NPIdentifier name) {
     (void)npobj; (void)name;
     print ("windowClassHasMehtod\n");
     return false;
 }
 
-static bool windowClassInvoke (NPObject *npobj, NPIdentifier method,
+static bool jsClassInvoke (NPObject *npobj, NPIdentifier method,
         const NPVariant *args, uint32_t arg_count, NPVariant *result) {
-    JsObject * jo = (JsObject *) npobj;
-    NPString str = { NULL, 0 };
-    char buf[512];
-    int pos, i;
-    bool res;
-    char * id = (char *) g_tree_lookup (identifiers, method);
-    /*print ("windowClassInvoke\n");*/
+    (void) npobj;
+    (void) method;
+    (void) args;
+    (void) arg_count;
+    return createUndefined (result);
+}
 
-    result->type = NPVariantType_Null;
-    result->value.objectValue = NULL;
+static bool jsClassInvokeDefault (NPObject *npobj,
+        const NPVariant *args, uint32_t arg_count, NPVariant *result) {
+    (void)npobj; (void)args; (void)arg_count; (void)result;
+    print ("jsClassInvokeDefault\n");
+    return false;
+}
 
-    if (!id) {
-        print ("Invoke invalid id\n");
-        return false;
-    }
-    print ("Invoke %s\n", id);
-    createJsName (jo, (char **)&str.utf8characters, &str.utf8length);
-    pos = snprintf (buf, sizeof (buf), "%s.%s(", str.utf8characters, id);
-    nsMemFree ((char *) str.utf8characters);
-    for (i = 0; i < arg_count; i++) {
-        char *arg = nsVariant2Str (args + i);
-        pos += snprintf (buf + pos, sizeof (buf) - pos, i ? ",%s" : "%s", arg);
-        nsMemFree (arg);
-    }
-    pos += snprintf (buf + pos, sizeof (buf) - pos, ")");
+static bool jsClassHasProperty (NPObject *npobj, NPIdentifier name) {
+    (void)npobj; (void)name;
+    print ("jsClassHasProperty\n");
+    return false;
+}
 
-    str.utf8characters = buf;
-    str.utf8length = pos;
-    res = doEvaluate (npp, npobj, &str, result);
+static bool jsClassGetProperty (NPObject *npobj, NPIdentifier property,
+        NPVariant *result) {
+    (void) npobj;
+    (void) property;
+    return createUndefined (result);
+}
+
+static bool jsClassSetProperty (NPObject *npobj, NPIdentifier property,
+        const NPVariant *value) {
+    (void) npobj;
+    (void) property;
+    (void) value;
 
     return true;
 }
 
-static bool windowClassInvokeDefault (NPObject *npobj,
-        const NPVariant *args, uint32_t arg_count, NPVariant *result) {
-    (void)npobj; (void)args; (void)arg_count; (void)result;
-    print ("windowClassInvokeDefault\n");
-    return false;
-}
-
-static bool windowClassHasProperty (NPObject *npobj, NPIdentifier name) {
+static bool jsClassRemoveProperty (NPObject *npobj, NPIdentifier name) {
     (void)npobj; (void)name;
-    print ("windowClassHasProperty\n");
+    print ("jsClassRemoveProperty\n");
     return false;
 }
 
 static bool windowClassGetProperty (NPObject *npobj, NPIdentifier property,
         NPVariant *result) {
     char * id = (char *) g_tree_lookup (identifiers, property);
-    JsObject jo;
-    NPString fullname = { NULL, 0 };
-    bool res;
-
-    print ("GetProperty %s\n", id);
-    result->type = NPVariantType_Null;
-    result->value.objectValue = NULL;
-
-    if (!id)
-        return false;
-
-    if (!strcmp (((JsObject *) npobj)->name, "window") &&
-                !strcmp (id, "top")) {
+    print ("windowClassGetProperty.GetProperty %s\n", id);
+    if (!strcmp (id, "location")) {
+        JsObject *jo = (JsObject*) nsCreateObject (NULL, &location_class);
+        jo->name = g_strdup ("location");
+        result->value.objectValue = (NPObject *) jo;
+        result->type = NPVariantType_Object;
+        return true;
+    } else if (!strcmp (id, "top")) {
+        result->value.objectValue = nsRetainObject (npobj);
         result->type = NPVariantType_Object;
-        result->value.objectValue = nsRetainObject (js_window);
         return true;
     }
-
-    jo.name = id;
-    jo.parent = (JsObject *) npobj;
-    createJsName (&jo, (char **)&fullname.utf8characters, &fullname.utf8length);
-
-    res = doEvaluate (npp, npobj, &fullname, result);
-
-    nsMemFree ((char *) fullname.utf8characters);
-
-    return res;
+    return jsClassGetProperty (npobj, property, result);
 }
 
-static bool windowClassSetProperty (NPObject *npobj, NPIdentifier property,
-        const NPVariant *value) {
-    char *id = (char *) g_tree_lookup (identifiers, property);
-    char *script, *var_name, *var_val, *res;
-    JsObject jo;
-    uint32_t len = 0;
-
-    if (!id)
-        return false;
-
-    jo.name = id;
-    jo.parent = (JsObject *) npobj;
-    createJsName (&jo, &var_name, &len);
-
-    var_val = nsVariant2Str (value);
-    script = (char *) nsAlloc (len + strlen (var_val) + 3);
-    sprintf (script, "%s=%s;", var_name, var_val);
-    nsMemFree (var_name);
-    nsMemFree (var_val);
-    print ("SetProperty %s\n", script);
-
-    res = browser_notify->evaluate (script, browser_data);
-    if (res)
-        g_free (res);
-    nsMemFree (script);
-
-
+static bool createStartLink (NPVariant *result) {
+    result->type = NPVariantType_String;
+    result->value.stringValue.utf8length = strlen (start_url);
+    result->value.stringValue.utf8characters = nsAlloc (strlen (start_url) + 1);
+    strcpy (result->value.stringValue.utf8characters, start_url);
     return true;
 }
 
-static bool windowClassRemoveProperty (NPObject *npobj, NPIdentifier name) {
-    (void)npobj; (void)name;
-    print ("windowClassRemoveProperty\n");
-    return false;
+static bool locationClassGetProperty (NPObject *npobj, NPIdentifier property,
+        NPVariant *result) {
+    char * id = (char *) g_tree_lookup (identifiers, property);
+    print ("locationClass.GetProperty %s\n", id);
+    if (!strcmp (id, "href"))
+        return createStartLink (result);
+    return jsClassGetProperty (npobj, property, result);
+}
+
+static bool locationClassInvoke (NPObject *npobj, NPIdentifier method,
+        const NPVariant *args, uint32_t arg_count, NPVariant *result) {
+    char *id = (char *) g_tree_lookup (identifiers, method);
+    print ("locationClass.Invoke %s\n", id);
+    if (!strcmp (id, "toString"))
+        return createStartLink (result);
+    return jsClassInvoke (npobj, method, args, arg_count, result);
 }
 
 
@@ -862,7 +716,7 @@ NPPluginLib *nppPluginInit (const char *lib) {
     print ("starting %s\n", lib);
     library = g_module_open (lib, G_MODULE_BIND_LAZY);
     if (!library) {
-        print ("failed to load\n");
+        print ("failed to load %s %s\n", lib, g_module_error ());
         return NULL;
     }
 
@@ -934,16 +788,23 @@ NPPluginLib *nppPluginInit (const char *lib) {
     ns_funcs.poppopupsenabledstate = nsPopPopupsEnabledState;
 
     js_class.structVersion = NP_CLASS_STRUCT_VERSION;
-    js_class.allocate = windowClassAllocate;
-    js_class.deallocate = windowClassDeallocate;
-    js_class.invalidate = windowClassInvalidate;
-    js_class.hasMethod = windowClassHasMethod;
-    js_class.invoke = windowClassInvoke;
-    js_class.invokeDefault = windowClassInvokeDefault;
-    js_class.hasProperty = windowClassHasProperty;
-    js_class.getProperty = windowClassGetProperty;
-    js_class.setProperty = windowClassSetProperty;
-    js_class.removeProperty = windowClassRemoveProperty;
+    js_class.allocate = jsClassAllocate;
+    js_class.deallocate = jsClassDeallocate;
+    js_class.invalidate = jsClassInvalidate;
+    js_class.hasMethod = jsClassHasMethod;
+    js_class.invoke = jsClassInvoke;
+    js_class.invokeDefault = jsClassInvokeDefault;
+    js_class.hasProperty = jsClassHasProperty;
+    js_class.getProperty = jsClassGetProperty;
+    js_class.setProperty = jsClassSetProperty;
+    js_class.removeProperty = jsClassRemoveProperty;
+
+    window_class = js_class;
+    window_class.getProperty = windowClassGetProperty;
+
+    location_class = js_class;
+    location_class.getProperty = locationClassGetProperty;
+    location_class.invoke = locationClassInvoke;
 
     np_funcs.size = sizeof (NPPluginFuncs);
 
@@ -972,7 +833,6 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     int i;
     int needs_xembed;
     unsigned int width = 0, height = 0;
-    GtkAllocation allocation;
 
     browser_data = ndata;
     browser_notify = notify;
@@ -1009,8 +869,8 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     display = gdk_x11_get_default_xdisplay ();
     np_window.x = 0;
     np_window.y = 0;
-    np_window.width = 800; /*width ? width : top_w;*/
-    np_window.height = 480; /*height ? height : top_h;*/
+    np_window.width = top_w; /*width ? width : top_w;*/
+    np_window.height = top_h; /*height ? height : top_h;*/
     np_window.window = (void*)socket_id;
     np_window.type = NPWindowTypeWindow;
     ws_info.type = NP_SETWINDOW;
@@ -1022,25 +882,24 @@ void *nppInstanceOpen (const char *mime, uint16_t argc, char *argn[],
     print ("display %u %dx%d\n", socket_id, np_window.width, np_window.height);
     np_window.ws_info = (void*)&ws_info;
 
-    allocation.x = 0;
-    allocation.y = 0;
-    allocation.width = np_window.width;
-    allocation.height = np_window.height;
-    gtk_widget_size_allocate (xembed, &allocation);
-
     np_err = np_funcs.setwindow (npp, &np_window);
 
     return npp;
 }
 
+void nppInstanceTopUrl (const char *url) {
+    g_free (start_url);
+    start_url = g_strdup (url);
+}
+
 void nppInstanceStart (const char *url, const char *mime, void *pdata) {
     (void) pdata;
     addStream (url, mime, 0L, 0, NULL, 0L, false);
 }
 
 void nppStreamData (uint32_t stream, const char *buf, uint32_t sz, void *p) {
-    (void)p;
     int written = writeStream (stream, buf, sz);
+    (void)p;
     if (written < sz)
         print ("FIXME: plugin didn't accept data %d written %d\n", sz, written);
 }
@@ -1086,102 +945,33 @@ void nppInstanceClose (void *pdata) {
         nsMemFree (npp);
         npp = 0L;
     }
+    g_free (start_url);
+    start_url = NULL;
     top_w = 0;
     top_h = 0;
+    np_window.window = NULL;
 }
 
-void nppInstanceWindowClose (void *p) {
-    (void)p;
-    if (top_widget)
-        gtk_widget_destroy (top_widget);
+void nppInstanceWindowClose (void *priv) {
+    Window r, p, *c;
+    unsigned int i, nr;
+    (void)priv;
+
     np_window.window = NULL;
-    top_widget = NULL;
+
+    Display *dpy = gdk_x11_get_default_xdisplay ();
+
+    if (XQueryTree (dpy, socket_id, &r, &p, &c, &nr)) {
+        print ("nppInstanceWindowClose chlds: %d\n", nr);
+        for (i = 0; i < nr; ++i)
+            XUnmapWindow (dpy, c[i]);
+        if (c)
+            XFree (c);
+    }
 }
 
 /*----------------%<---------------------------------------------------------*/
 
-static void pluginAdded (GtkSocket *socket, gpointer d) {
-    /*(void)socket;*/ (void)d;
-    print ("pluginAdded\n");
-    if (socket->plug_window) {
-        gpointer user_data = NULL;
-        gdk_window_get_user_data (socket->plug_window, &user_data);
-        if (!user_data) {
-            /**
-             * GtkSocket resets plugins XSelectInput in
-             * _gtk_socket_add_window
-             *   _gtk_socket_windowing_select_plug_window_input
-             **/
-            XSelectInput (gdk_x11_get_default_xdisplay (),
-                    gdk_x11_drawable_get_xid (socket->plug_window),
-                    KeyPressMask | KeyReleaseMask |
-                    ButtonPressMask | ButtonReleaseMask |
-                    KeymapStateMask |
-                    ButtonMotionMask |
-                    PointerMotionMask |
-                    EnterWindowMask | LeaveWindowMask |
-                    FocusChangeMask |
-                    ExposureMask |
-                    StructureNotifyMask |
-                    SubstructureRedirectMask |
-                    PropertyChangeMask
-                    );
-        }
-    }
-    browser_notify->embedded (browser_data);
-}
-
-static void windowCreatedEvent (GtkWidget *w, gpointer d) {
-    (void)d;
-    socket_id = gtk_socket_get_id (GTK_SOCKET (xembed));
-    print ("windowCreatedEvent socket:%d\n", socket_id);
-    if (parent_id) {
-        /*print ("windowCreatedEvent %p\n", GTK_PLUG (w)->socket_window);*/
-        /*if (!GTK_PLUG (w)->socket_window)
-            gtk_plug_construct (GTK_PLUG (w), parent_id);*/
-        gdk_window_reparent( w->window,
-                gdk_window_lookup (parent_id),
-                0, 0);
-        if (top_w > 0 && top_h > 0)
-            nppInstanceWindowDimension (npp, 0, 0, top_w, top_h);
-        gtk_widget_show_all (w);
-        /*XReparentWindow (gdk_x11_drawable_get_xdisplay (w->window),
-                gdk_x11_drawable_get_xid (w->window),
-                parent_id,
-                0, 0);*/
-    }
-}
-
-/*static void embeddedEvent (GtkPlug *plug, gpointer d) {
-    (void)plug; (void)d;
-    print ("embeddedEvent\n");
-}*/
-
-static gboolean configureEvent(GtkWidget *w, GdkEventConfigure *e, gpointer d) {
-    (void)w; (void)d;
-    if (np_window.window &&
-            (e->width != np_window.width || e->height != np_window.height)) {
-        print ("Update size %dx%d\n", e->width, e->height);
-        np_window.width = e->width;
-        np_window.height = e->height;
-        np_funcs.setwindow (npp, &np_window);
-    }
-    return FALSE;
-}
-
-static gboolean windowCloseEvent (GtkWidget *w, GdkEvent *e, gpointer d) {
-    (void)w; (void)e; (void)d;
-    print ("windowCloseEvent\n");
-    /*shutDownPlugin();*/
-    return FALSE;
-}
-
-static void windowDestroyEvent (GtkWidget *w, gpointer d) {
-    (void)w; (void)d;
-    print ("windowDestroyEvent\n");
-    /*gtk_main_quit();*/
-}
-
 static gboolean updateDimension (void * p) {
     (void)p;
     if (np_window.window &&
@@ -1196,62 +986,16 @@ static gboolean updateDimension (void * p) {
 
 void nppInstanceWindowDimension (void *p, int x, int y, int w, int h) {
     (void)p; (void) x; (void) y;
-    if (top_widget) {
-        print ("nppInstanceWindowDimension %dx%d\n", w, h);
-        gdk_window_move_resize (top_widget->window, 0, 0, w, h);
-        if (!update_dimension_timer)
-            update_dimension_timer = g_timeout_add (100, updateDimension, NULL);
-    }
+    print ("nppInstanceWindowDimension %dx%d\n", w, h);
+    if (!update_dimension_timer)
+      update_dimension_timer = g_timeout_add (100, updateDimension, NULL);
     top_w = w;
     top_h = h;
 }
 
 void nppInstanceWindowParent (void *p, void * wid) {
-    GdkColormap *color_map;
-    GdkColor bg_color;
     (void)p;
-    /*GdkWindow *parent;*/
-
-    parent_id = (Window) wid;
-
-    top_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    g_signal_connect (G_OBJECT (top_widget), "delete_event",
-            G_CALLBACK (windowCloseEvent), NULL);
-    g_signal_connect (G_OBJECT (top_widget), "destroy",
-            G_CALLBACK (windowDestroyEvent), NULL);
-    g_signal_connect_after (G_OBJECT (top_widget), "realize",
-            GTK_SIGNAL_FUNC (windowCreatedEvent), NULL);
-    /*g_signal_connect (G_OBJECT (top_widget), "configure-event",
-            GTK_SIGNAL_FUNC (configureEvent), NULL);*/
-
-    xembed = gtk_socket_new();
-    g_signal_connect (G_OBJECT (xembed), "plug-added",
-            GTK_SIGNAL_FUNC (pluginAdded), NULL);
-    /*g_signal_connect_after (G_OBJECT (xembed), "realize",
-            GTK_SIGNAL_FUNC (windowCreatedEvent), NULL);*/
-
-    color_map = gdk_colormap_get_system();
-    gdk_colormap_query_color (color_map, 0, &bg_color);
-    gtk_widget_modify_bg (xembed, GTK_STATE_NORMAL, &bg_color);
-
-    gtk_container_add (GTK_CONTAINER (top_widget), xembed);
-
-    gtk_widget_set_size_request (top_widget, 800, 480); /*top_w, top_h);*/
-
-    /*g_signal_connect (G_OBJECT (top_widget), "embedded",
-            GTK_SIGNAL_FUNC (embeddedEvent), NULL);*/
-
-    /*parent = gdk_window_lookup (parent_id);
-    print ("parent gdk window %p\n", parent);
-    gtk_widget_set_parent_window (xembed, parent);
-
-    gtk_widget_map (xembed);
-
-    socket_id = gtk_socket_get_id (GTK_SOCKET (xembed));
-    print ("socket %u\n", socket_id);
-    */
-
-    gtk_widget_realize (top_widget);
+    socket_id = (Window) wid;
 }
 
 
